@@ -1,11 +1,6 @@
-import logging
-
 from rgd.management.commands._data_helper import SynchronousTasksCommand, _get_or_create_file_model
 from rgd_3d import models
 
-logger = logging.getLogger(__name__)
-
-
 SUCCESS_MSG = 'Finished loading all demo data.'
 
 # Names of files in the datastore
@@ -14,10 +9,10 @@ POINT_CLOUD_FILES = [
 ]
 
 
-def load_point_cloud_files(pc_files):
+def load_mesh_3d_files(pc_files):
     ids = []
     for f in pc_files:
-        entry = _get_or_create_file_model(models.PointCloud, f)
+        entry = _get_or_create_file_model(models.Mesh3D, f)
         ids.append(entry.pk)
     return ids
 
@@ -29,7 +24,7 @@ class Command(SynchronousTasksCommand):
 
         self.set_synchronous()
         # Run the command
-        load_point_cloud_files(POINT_CLOUD_FILES)
+        load_mesh_3d_files(POINT_CLOUD_FILES)
 
         self.stdout.write(self.style.SUCCESS(SUCCESS_MSG))
         self.reset_celery()
