@@ -5,7 +5,7 @@ from rgd.utility import skip_signal
 from rgd_3d import models
 
 
-@receiver(post_save, sender=models.PointCloud)
+@receiver(post_save, sender=models.Mesh3D)
 @skip_signal()
-def _post_save_point_cloud_file(sender, instance, *args, **kwargs):
+def _post_save_mesh_3d_file(sender, instance, *args, **kwargs):
     transaction.on_commit(lambda: instance._post_save_event_task(*args, **kwargs))
