@@ -4,8 +4,8 @@ from rgd_3d import models
 from rgd_testing_utils.factories import ChecksumFileFactory
 
 
-class PointCloudFactory(factory.django.DjangoModelFactory):
+class Mesh3DFactory(factory.django.DjangoModelFactory):
     class Meta:
-        model = models.PointCloud
+        model = models.Mesh3D
 
     file = factory.SubFactory(ChecksumFileFactory)
